﻿function Get-ConcatJobs
{
    [CmdletBinding(SupportsShouldProcess=$true, 
                  PositionalBinding=$false,
                  ConfirmImpact='Medium')]
    [Alias()]
    [OutputType([PSOBJECT])]

    param (
        [Parameter(Mandatory=$True, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [PSObject]$ELHCConfig = $false,

        [Parameter(Mandatory=$False, ParameterSetName='External')]
        [ValidateNotNullOrEmpty()]
        [string]$ConnectionString = "data source=(local);initial catalog=WGEvidenceLibrary;integrated security=true;connection lifetime=30;"
    )

    if($ELHCConfig) {
        $ConnectionString = $ELHCConfig.root.ConnectionString
    }

    $Query = "select COUNT(*) as Pending from JobQueue.ConcatEventQueue where SubstationID = '$($ELHCConfig.root.substationID)'"

    $ConcatCount = (Get-QueryResult -query $Query -connectionString $ConnectionString).Pending
    
    $AlertBool = $false
    $AlertJobs = [int]$ELHCConfig.root.components.standalone.concatjobs.alerts.allowedjobs
    if ($AlertJobs -lt $TranscodeCount) {
        $AlertBool = $true
    }

    $Results = @{
        'LogType' = "ConcatJobs"
        'ConcatsPending' = $ConcatCount
        'AlertJobs' = $AlertJobs
        'AlertBool' = $AlertBool
    }

    return $Results
}